@@ -190,6 +190,10 @@ class UnsupportedFileType(Exception):
     pass
 
 
+class UnsupportedBrowser(Exception):
+    pass
+
+
 class UtilityAPI:
     def __init__(
         self,
@@ -198,6 +202,7 @@ class UtilityAPI:
         data_path=None,
         file_ext=".csv",
         headless=True,
+        browser="Firefox",
         timeout=10,
         save_statements=True,
         google_sa_credentials=None,
@@ -205,7 +210,7 @@ class UtilityAPI:
         self._user = user
         self._password = password
         self._driver = None
-        self._browser = None
+        self._browser = browser
         self._headless = headless
         self._temp_download_dir = tempfile.mkdtemp()
         self._data_path = data_path or os.path.abspath(os.path.join(".", "data"))
@@ -223,7 +228,16 @@ class UtilityAPI:
         if self._file_ext not in supported_filetypes:
             raise UnsupportedFileType(
                 f"`file_ext`={self._file_ext} has an invalid filetype. Acceptable extensions are "
-                f'{",".join([f"`{x}`" for x in supported_filetypes])}'
+                + ",".join([f'"{x}"' for x in supported_filetypes])
+                + "."
+            )
+
+        supported_browsers = ["Chrome", "Firefox"]
+        if self._browser not in supported_browsers:
+            raise UnsupportedBrowser(
+                f"`browser`={self._browser} is invalid. Supported browsers are "
+                + ",".join([f'"{x}"' for x in supported_browsers])
+                + "."
             )
 
         self._monthly_history = pd.DataFrame()
@@ -263,8 +277,7 @@ class UtilityAPI:
                 os.path.join(self._data_path, self.name, "monthly" + self._file_ext)
             ).set_index("Date")
 
-    def _init_driver(self, browser="Firefox"):
-        self._browser = browser
+    def _init_driver(self):
         if self._browser == "Chrome":
             options = webdriver.ChromeOptions()
             prefs = {"download.default_directory": self._temp_download_dir}
