@@ -238,6 +238,7 @@ class KitchenerUtilitiesAPI(UtilityAPI):
         data_path=None,
         file_ext=".csv",
         headless=True,
+        browser="Firefox",
         timeout=10,
         save_statements=True,
         google_sa_credentials=None,
@@ -248,6 +249,7 @@ class KitchenerUtilitiesAPI(UtilityAPI):
             data_path=data_path,
             file_ext=file_ext,
             headless=headless,
+            browser=browser,
             timeout=timeout,
             save_statements=save_statements,
             google_sa_credentials=google_sa_credentials,
